@@ -31,7 +31,8 @@ func main() {
 		rules.AdobeClientID(),
 		rules.AdobeClientSecret(),
 		rules.AgeSecretKey(),
-		rules.Airtable(),
+		rules.AirtableApiKey(),
+		rules.AirtablePersonalAccessToken(),
 		rules.AlgoliaApiKey(),
 		rules.AlibabaAccessKey(),
 		rules.AlibabaSecretKey(),
@@ -152,6 +153,8 @@ func main() {
 		rules.LinkedinClientSecret(),
 		rules.LobAPIToken(),
 		rules.LobPubAPIToken(),
+		rules.LookerClientID(),
+		rules.LookerClientSecret(),
 		rules.MailChimp(),
 		rules.MailGunPubAPIToken(),
 		rules.MailGunPrivateAPIToken(),
